==> dde-launcher_4.4.5.5.orig.tar.xz: dde-launcher-4.4.5.5/translations/dde-launcher_id.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="id" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation>Tidak ada hasil pencarian</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chat</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Video</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Game</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Office</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reading</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Development</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Others</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>Anda yakin untuk melepas %1?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Konfirmasi</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>Hapus dari destop</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>Lepas dari dok</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>Hapus instal</translation>
    </message>
    <message>
        <source>Open by proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open</source>
        <translation>Buka</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Send to dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add to startup</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation>Semua Aplikasi</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Obrolan</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musik</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Grafik</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Permainan</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Perkantoran</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Bacaan</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Pengembangan</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistem</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Lainnya</translation>
    </message>
</context>
<context>
    <name>MiniFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>Anda yakin untuk melepas %1?</translation>
    </message>
    <message>
        <source>All dependencies will be removed together</source>
        <translation>Semua dependensi akan dihapus</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Konfirmasi</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>Komputer</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumen</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musik</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Gambar</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Unduh</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Kunci</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Keluar</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Boot ulang</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Tangguhkan</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Matikan</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Kembali</translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>Komputer</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musik</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Matikan</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Kunci</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Keluar</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Boot ulang</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Tangguhkan</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Kembali</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumen</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Gambar</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Unduh</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>Komputer</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musik</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Unduh</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Pengaturan</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Matikan</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Gambar</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Cari</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>Anda yakin untuk melepas %1?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Konfirmasi</translation>
    </message>
</context>
</TS>

==> dde-launcher_5.0.14.orig.tar.xz: dde-launcher-5.0.14/translations/dde-launcher_id.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="id" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation>Tidak ada hasil pencarian</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Obrolan</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musik</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Grafik</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Perkantoran</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Bacaan</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Pengembangan</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistem</translation>
    </message>
    <message>
        <source>Games</source>
        <translation>Permainan</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Lainnya</translation>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Konfirmasi</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>Hapus dari destop</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>Lepas dari dok</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>Hapus instal</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation>Non aktif tampilan skala</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Buka</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>Kirim ke desktop</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation>Kirim ke dock</translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation>Buang dari tampilan awal</translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation>Tambah ke tampilan awal</translation>
    </message>
    <message>
        <source>Use a proxy</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation>Semua Aplikasi</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Obrolan</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musik</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Grafik</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Permainan</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Perkantoran</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Bacaan</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Pengembangan</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistem</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Lainnya</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>Komputer</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumen</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musik</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Gambar</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Unduh</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Kunci</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Keluar</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Boot ulang</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Tangguhkan</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Matikan</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Kembali</translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>Komputer</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musik</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Matikan</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Kunci</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Keluar</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Boot ulang</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Tangguhkan</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Kembali</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumen</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Gambar</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Unduh</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>Komputer</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musik</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Unduh</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Pengaturan</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Gambar</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumen</translation>
    </message>
    <message>
        <source>Power</source>
        <translation>Daya</translation>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation>Semua Kategori</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Kembali</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Cari</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Konfirmasi</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
